@@ -367,7 +367,7 @@ def updatedb(procdb,minage=0):
 
    """
    if os.path.isfile(procdb):
-      newpsi = alluseful()
+      newpsi = alluseful(minage)
       oldpsi = scandb(procdb)
       for ops in oldpsi:
          for nps in newpsi:
